aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/dom/xrrigidtransform.rs
diff options
context:
space:
mode:
authorMartin Robinson <mrobinson@igalia.com>2023-01-16 17:46:27 +0100
committerMartin Robinson <mrobinson@igalia.com>2023-01-26 08:59:21 +0100
commit423cc34cb00c698313c67a0edcbc6721ecf04f4f (patch)
tree46f5231f40db8052fc2979ab72594f1e44501136 /components/script/dom/xrrigidtransform.rs
parent4f355f5877878bb2f4aed2b471e82722cd43f8e1 (diff)
downloadservo-423cc34cb00c698313c67a0edcbc6721ecf04f4f.tar.gz
servo-423cc34cb00c698313c67a0edcbc6721ecf04f4f.zip
Bump euclid to 0.22
- Also updates raqote to latest with an upgrade of font-kit to 0.11 applied on as a patch - Update lyon_geom to the latest version Major change: - All matrices are now stored in row major order. This means that parameters to rotation functions no longer should be negated. - `post_...()` functions are now named `then()`. `pre_transform()` is removed, so `then()` is used and the order of operations changed.
Diffstat (limited to 'components/script/dom/xrrigidtransform.rs')
-rw-r--r--components/script/dom/xrrigidtransform.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/components/script/dom/xrrigidtransform.rs b/components/script/dom/xrrigidtransform.rs
index ac752d5a3dd..0488d4584eb 100644
--- a/components/script/dom/xrrigidtransform.rs
+++ b/components/script/dom/xrrigidtransform.rs
@@ -119,8 +119,8 @@ impl XRRigidTransformMethods for XRRigidTransform {
if self.matrix.get().is_null() {
let cx = self.global().get_cx();
// According to the spec all matrices are column-major,
- // however euclid uses row vectors so we use .to_row_major_array()
- let arr = self.transform.to_transform().to_row_major_array();
+ // however euclid uses row vectors so we use .to_array()
+ let arr = self.transform.to_transform().to_array();
create_typed_array(cx, &arr, &self.matrix);
}
NonNull::new(self.matrix.get()).unwrap()